# PyBujo
 
 A cli for tracking ..things

| Command  | Options              | Result |
| -------- | -------              | ------ |
| add      | -b --bujo            | Adds a not to the specified bujo         |
| fig      |--words -w, --color -c| Prints some cool text                    |
| ls       |                      | Lists the specified bujo                 |
| rm       |                      | Removes an item from a bujo via its index|

